@@ -16,15 +16,23 @@
 # under the License.
 
 
-__all__ = ["settings", "resource_path"]
+__all__ = ["huge_settings", "admin_settings", "llm_settings", "resource_path", "index_settings"]
 
 import os
-from .config import Config, PromptConfig
 
-settings = Config()
-settings.from_env()
-prompt = PromptConfig()
+from .admin_config import AdminConfig
+from .hugegraph_config import HugeGraphConfig
+from .index_config import IndexConfig
+from .llm_config import LLMConfig
+from .prompt_config import PromptConfig
+
+llm_settings = LLMConfig()
+prompt = PromptConfig(llm_settings)
 prompt.ensure_yaml_file_exists()
 
+huge_settings = HugeGraphConfig()
+admin_settings = AdminConfig()
+index_settings = IndexConfig()
+
 package_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 resource_path = os.path.join(package_path, "resources")
