@@ -53,7 +53,8 @@ class DisambiguateData:
             extract_triples_by_regex(llm_output, data)
             print(
                 f"LLM {self.__class__.__name__} input:{prompt} \n"
-                f" output: {llm_output} \n data: {data}")
+                f" output: {llm_output} \n data: {data}"
+            )
             data["call_count"] = data.get("call_count", 0) + 1
 
         return data
