@@ -84,9 +84,7 @@ class AuthManager(HugeParamsBase):
         return self._invoke_request(data=json.dumps(data))
 
     @router.http("DELETE", "auth/groups/{group_id}")
-    def delete_group(
-        self, group_id  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+    def delete_group(self, group_id) -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("PUT", "auth/groups/{group_id}")
@@ -116,23 +114,19 @@ class AuthManager(HugeParamsBase):
         )
 
     @router.http("DELETE", "auth/accesses/{access_id}")
-    def revoke_accesses(
-        self, access_id  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+    def revoke_accesses(self, access_id) -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("PUT", "auth/accesses/{access_id}")
     def modify_accesses(
-        self, access_id, access_description  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+        self, access_id, access_description
+    ) -> Optional[Dict]:  # pylint: disable=unused-argument
         # The permission of access can\'t be updated
         data = {"access_description": access_description}
         return self._invoke_request(data=json.dumps(data))
 
     @router.http("GET", "auth/accesses/{access_id}")
-    def get_accesses(
-        self, access_id  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+    def get_accesses(self, access_id) -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("GET", "auth/accesses")
@@ -180,8 +174,8 @@ class AuthManager(HugeParamsBase):
 
     @router.http("GET", "auth/targets/{target_id}")
     def get_target(
-        self, target_id, response=None  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+        self, target_id, response=None
+    ) -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("GET", "auth/targets")
@@ -199,15 +193,13 @@ class AuthManager(HugeParamsBase):
 
     @router.http("PUT", "auth/belongs/{belong_id}")
     def update_belong(
-        self, belong_id, description  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+        self, belong_id, description
+    ) -> Optional[Dict]:  # pylint: disable=unused-argument
         data = {"belong_description": description}
         return self._invoke_request(data=json.dumps(data))
 
     @router.http("GET", "auth/belongs/{belong_id}")
-    def get_belong(
-        self, belong_id  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+    def get_belong(self, belong_id) -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("GET", "auth/belongs")
