@@ -64,15 +64,13 @@ class SchemaManager(HugeParamsBase):
         return index_label
 
     @router.http("GET", "schema?format={_format}")
-    def getSchema(
-        self, _format: str = "json"  # pylint: disable=unused-argument
-    ) -> Optional[Dict]:
+    def getSchema(self, _format: str = "json") -> Optional[Dict]:  # pylint: disable=unused-argument
         return self._invoke_request()
 
     @router.http("GET", "schema/propertykeys/{property_name}")
     def getPropertyKey(
-        self, property_name  # pylint: disable=unused-argument
-    ) -> Optional[PropertyKeyData]:
+        self, property_name
+    ) -> Optional[PropertyKeyData]:  # pylint: disable=unused-argument
         if response := self._invoke_request():
             return PropertyKeyData(response)
         return None
@@ -84,9 +82,7 @@ class SchemaManager(HugeParamsBase):
         return None
 
     @router.http("GET", "schema/vertexlabels/{name}")
-    def getVertexLabel(
-        self, name  # pylint: disable=unused-argument
-    ) -> Optional[VertexLabelData]:
+    def getVertexLabel(self, name) -> Optional[VertexLabelData]:  # pylint: disable=unused-argument
         if response := self._invoke_request():
             return VertexLabelData(response)
         log.error("VertexLabel not found: %s", str(response))
@@ -100,8 +96,8 @@ class SchemaManager(HugeParamsBase):
 
     @router.http("GET", "schema/edgelabels/{label_name}")
     def getEdgeLabel(
-        self, label_name: str  # pylint: disable=unused-argument
-    ) -> Optional[EdgeLabelData]:
+        self, label_name: str
+    ) -> Optional[EdgeLabelData]:  # pylint: disable=unused-argument
         if response := self._invoke_request():
             return EdgeLabelData(response)
         log.error("EdgeLabel not found: %s", str(response))
@@ -128,9 +124,7 @@ class SchemaManager(HugeParamsBase):
         return None
 
     @router.http("GET", "schema/indexlabels/{name}")
-    def getIndexLabel(
-        self, name  # pylint: disable=unused-argument
-    ) -> Optional[IndexLabelData]:
+    def getIndexLabel(self, name) -> Optional[IndexLabelData]:  # pylint: disable=unused-argument
         if response := self._invoke_request():
             return IndexLabelData(response)
         log.error("IndexLabel not found: %s", str(response))
