@@ -20,6 +20,7 @@ import json
 import traceback
 
 import requests
+
 from pyhugegraph.utils.exceptions import (
     NotAuthorizedError,
     NotFoundError,
@@ -29,12 +30,15 @@ from pyhugegraph.utils.log import log
 
 
 def create_exception(response_content):
-    data = json.loads(response_content)
-    if "ServiceUnavailableException" in data["exception"]:
-        raise ServiceUnavailableException(
-            f'ServiceUnavailableException, "message": "{data["message"]}",'
-            f' "cause": "{data["cause"]}"'
-        )
+    try:
+        data = json.loads(response_content)
+        if "ServiceUnavailableException" in data.get("exception", ""):
+            raise ServiceUnavailableException(
+                f'ServiceUnavailableException, "message": "{data["message"]}",'
+                f' "cause": "{data["cause"]}"'
+            )
+    except (json.JSONDecodeError, KeyError) as e:
+        raise Exception(f"Error parsing response content: {response_content}") from e
     raise Exception(response_content)
 
 
@@ -47,20 +51,18 @@ def check_if_authorized(response):
 
 
 def check_if_success(response, error=None):
-    if (not str(response.status_code).startswith("20")) and check_if_authorized(
-            response
-    ):
+    if (not str(response.status_code).startswith("20")) and check_if_authorized(response):
         if error is None:
             error = NotFoundError(response.content)
 
         req = response.request
         req_body = req.body if req.body else "Empty body"
         response_body = response.text if response.text else "Empty body"
-        # Log the detailed information
-        print(
-            f"\033[93mError-Client:\n"
-            f"Request URL: {req.url}, Request Body: {req_body}\nResponse Body: "
-            f"{response_body}\033[0m"
+        log.error(
+            "Error-Client: Request URL: %s, Request Body: %s, Response Body: %s",
+            req.url,
+            req_body,
+            response_body,
         )
         raise error
     return True
@@ -107,19 +109,23 @@ class ResponseValidation:
                     details = "key 'exception' not found"
 
                 req_body = response.request.body if response.request.body else "Empty body"
-                req_body = req_body.encode('utf-8').decode('unicode_escape')
-                log.error(  # pylint: disable=logging-fstring-interpolation
-                    f"{method}: {e}\n[Body]: {req_body}\n[Server Exception]: {details}"
+                req_body = req_body.encode("utf-8").decode("unicode_escape")
+                log.error(
+                    "%s: %s\n[Body]: %s\n[Server Exception]: %s",
+                    method,
+                    str(e).encode("utf-8").decode("unicode_escape"),
+                    req_body,
+                    details,
                 )
 
                 if response.status_code == 404:
                     raise NotFoundError(response.content) from e
+                if response.status_code == 400:
+                    raise Exception(f"Server Exception: {details}") from e
                 raise e
 
         except Exception:  # pylint: disable=broad-exception-caught
-            log.error(  # pylint: disable=logging-fstring-interpolation
-                f"Unhandled exception occurred: {traceback.format_exc()}"
-            )
+            log.error("Unhandled exception occurred: %s", traceback.format_exc())
 
         return result
 
